import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class TextFormInput extends StatefulWidget {
  final String? text;
  final String label;
  final String? errorText;
  final ValueChanged<String>? onChanged;
  final String? hintText;
  final Widget? icon;
  final int minLines;
  final int maxLines;
  final int? maxLength;
  final bool enabled;
  final bool isPassword;
  final bool autoFocus;
  final FocusNode? focusNode;
  final EdgeInsetsGeometry? contentPadding;
  final TextEditingController? controller;
  final TextInputType? keyboardType;
  final TextInputAction? textInputAction;
  final List<TextInputFormatter>? inputFormatters;
  final FormFieldValidator<String>? validator;
  final Function(String)? onSubmited;

  const TextFormInput(
      {Key? key,
      this.text,
      this.icon,
      this.autoFocus = false,
      this.isPassword = false,
      this.controller,
      this.hintText,
      this.keyboardType,
      this.minLines = 1,
      this.maxLines = 1,
      this.enabled = true,
      this.contentPadding,
      this.maxLength,
      this.inputFormatters,
      this.errorText,
      required this.label,
      this.onChanged,
      this.textInputAction,
      this.focusNode,
      this.onSubmited,
      this.validator})
      : super(key: key);

  @override
  _TextFormInputState createState() => _TextFormInputState();
}

class _TextFormInputState extends State<TextFormInput> {
  bool focado = false;

  @override
  void initState() {
    focado = widget.autoFocus;

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Focus(
        onFocusChange: (hasFocus) {
          setState(() {
            focado = hasFocus;
          });
        },
        child: TextFormField(
          autovalidateMode: AutovalidateMode.onUserInteraction,
          onChanged: widget.onChanged,
          maxLength: widget.maxLength,
          minLines: widget.minLines, //Normal textInputField will be displayed
          maxLines: widget.maxLines, //
          enabled: widget.enabled, //
          initialValue: widget.text,
          validator: widget.validator,
          obscureText: widget.isPassword,
          controller: widget.controller,
          autofocus: widget.autoFocus,
          textCapitalization: TextCapitalization.words,
          focusNode: widget.focusNode,
          keyboardType: widget.keyboardType,
          textAlign: TextAlign.start,
          textInputAction: widget.textInputAction,
          onFieldSubmitted: widget.onSubmited,
          cursorColor: Colors.white,
          decoration: InputDecoration(
            errorText:
                (this.widget.errorText == null ? null : this.widget.errorText),
            errorStyle: TextStyle(
                letterSpacing: 0.5,
                fontSize: 14.0,
                fontWeight: FontWeight.w600),
            contentPadding:
                widget.contentPadding ?? EdgeInsets.only(left: 20.0, right: 10),
            hintText: widget.hintText,
            filled: true,
            labelText: widget.label,
            suffixIcon: widget.icon,
          ),
        ),
      ),
    );
  }
}
